pub struct TimestampCapabilities {
pub software_tx: bool,
pub software_rx: bool,
pub hardware_tx: bool,
pub hardware_rx: bool,
}Expand description
Timestamping capabilities of a network interface.
Fields
software_tx: boolsoftware_rx: boolhardware_tx: boolhardware_rx: boolImplementations
Sourceimpl TimestampCapabilities
impl TimestampCapabilities
Sourcepub fn query(interface_name: &str) -> Result<Self>
pub fn query(interface_name: &str) -> Result<Self>
Query the timestamping capabilities of a network interface (Linux).
Uses a best-effort approach:
- Checks if the interface exists via
/sys/class/net/{iface}. - Checks if it has a backing hardware device via
/sys/class/net/{iface}/device/. Hardware devices with PCI backing often support hardware timestamping. - Attempts
SIOCETHTOOLwithETHTOOL_GET_TS_INFOioctl for precise capability detection. - Falls back to
software_only()if detection fails.
Software timestamping is always assumed available on Linux (kernel provides it).
Sourcepub fn software_only() -> Self
pub fn software_only() -> Self
Return default software-only capabilities (fallback).
Sourcepub fn has_hardware(&self) -> bool
pub fn has_hardware(&self) -> bool
Whether any form of hardware timestamping is available.
Sourcepub fn has_software(&self) -> bool
pub fn has_software(&self) -> bool
Whether software timestamping is available (always true on Linux/FreeBSD).